@@ -2,7 +2,8 @@ import pyvisa
 import time
 import numpy as np
 rm = pyvisa.ResourceManager()
-
+name = "Shutter"
+hwid = ["software"]
 class Shutter:
     def __init__(self):
         rm = pyvisa.ResourceManager()
